@@ -702,7 +702,19 @@ class BaseWatcher(ABC):
                     def data_version_getter(q: Queue = queue) -> int | None:
                         return q.get_data_version()
 
-                    self._strategy.start(data_version_getter)
+                    # Seed last_ts before polling so watchers have an initial value
+                    try:
+                        queue.refresh_last_ts()
+                    except Exception:
+                        logger.debug("Initial last_ts refresh failed", exc_info=True)
+
+                    def on_data_version_change(q: Queue = queue) -> None:
+                        q.refresh_last_ts()
+
+                    self._strategy.start(
+                        data_version_getter,
+                        on_data_version_change=on_data_version_change,
+                    )
 
                 # Initial drain of existing messages
                 self._drain_queue()
@@ -716,6 +728,9 @@ class BaseWatcher(ABC):
             except _StopLoop:
                 # Normal shutdown
                 break
+            except KeyboardInterrupt:
+                # Propagate KeyboardInterrupt so callers can handle it specifically
+                raise
             except Exception as e:
                 retry_count += 1
                 if not self._handle_retry(e, retry_count, max_retries):
@@ -729,6 +744,7 @@ class BaseWatcher(ABC):
         # Default implementation - just stop
         logger.info("Received SIGINT, stopping watcher...")
         self.stop(join=False)
+        raise KeyboardInterrupt
 
     def _safe_call_handler(
         self,
@@ -1018,6 +1034,7 @@ class PollingStrategy:
         self._stop_event = stop_event
         self._data_version: int | None = None
         self._data_version_provider: Callable[[], int | None] | None = None
+        self._data_change_callback: Callable[[], None] | None = None
         self._pragma_failures = 0
         self._jitter_factor = jitter_factor
 
@@ -1053,12 +1070,16 @@ class PollingStrategy:
         self._check_count = 0
 
     def start(
-        self, data_version_provider: Callable[[], int | None] | None = None
+        self,
+        data_version_provider: Callable[[], int | None] | None = None,
+        *,
+        on_data_version_change: Callable[[], None] | None = None,
     ) -> None:
         """Initialize the strategy."""
         self._data_version_provider = data_version_provider
         self._check_count = 0
         self._data_version = None
+        self._data_change_callback = on_data_version_change
 
     def _get_delay(self) -> float:
         """Calculate delay based on check count."""
@@ -1098,6 +1119,12 @@ class PollingStrategy:
                 return False
             if version != self._data_version:
                 self._data_version = version
+                if self._data_change_callback is not None:
+                    try:
+                        self._data_change_callback()
+                    except Exception:
+                        # Swallow callback exceptions so polling continues
+                        logger.exception("data_version change callback failed")
                 return True  # Change detected!
 
             return False
